@@ -2,6 +2,8 @@ import click
 import pathlib
 import typing as t
 
+from click_params import FirstOf
+
 from .commands.ScanCommand import ScanCommand
 from .commands.UploadCommand import UploadCommand
 
@@ -11,9 +13,9 @@ def _start():
 
 @_start.command(cls=ScanCommand)
 @click.option('-o', '--output', 'output_path', required=False, type=click.Path(path_type=pathlib.Path), help='Output path for the scan')
-@click.argument('path', type=click.Path(exists=True, path_type=pathlib.Path), nargs=-1)
-def scan(path, output_path, *args, **kwargs):
-    scan.run(list(path), output_path, *args, **kwargs)
+@click.argument('sources', type=FirstOf(click.Path(exists=True, path_type=pathlib.Path), click.STRING), nargs=-1)
+def scan(sources, output_path, *args, **kwargs):
+    scan.run(list(sources), output_path, *args, **kwargs)
 
 
 @_start.command(cls=UploadCommand)
